@@ -1,8 +1,9 @@
-// $Id$
+// $Id$ -*- C++ -*-
 // Communicate with separate GDB process
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
 // Copyright (C) 2000 Universitaet Passau, Germany.
+// Copyright (C) 2003, 2004, 2008 Free Software Foundation, Inc.
 // Written by Dorothea Luetkehaus <luetke@ips.cs.tu-bs.de>
 // and Andreas Zeller <zeller@gnu.org>.
 // 
@@ -11,7 +12,7 @@
 // DDD is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// version 3 of the License, or (at your option) any later version.
 // 
 // DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +21,7 @@
 // 
 // You should have received a copy of the GNU General Public
 // License along with DDD -- see the file COPYING.
-// If not, write to the Free Software Foundation, Inc.,
-// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// If not, see <http://www.gnu.org/licenses/>.
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
@@ -53,7 +53,8 @@
 // Debugger types
 //-----------------------------------------------------------------------------
 
-enum DebuggerType { BASH, DBG, DBX, GDB, JDB, PERL, PYDB, XDB };
+enum DebuggerType { BASH, DBG, DBX, GDB, JDB, PERL, PYDB, XDB, MAKE };
+enum DebuggerCPU { cpu_intel, cpu_unknown};
 //-----------------------------------------------------------------------------
 // Program language
 //-----------------------------------------------------------------------------
@@ -69,6 +70,7 @@ enum ProgramLanguage {
     LANGUAGE_CHILL,		// Chill, as supported by GDB.
     LANGUAGE_FORTRAN,		// FORTRAN, as supported by GDB.
     LANGUAGE_JAVA,		// Java, as supported by GDB.
+    LANGUAGE_MAKE,		// Make, as supported by mdb.
     LANGUAGE_PASCAL,		// Pascal-like: Pascal, Modula...
     LANGUAGE_PERL,		// Perl, as supported by Perl.
     LANGUAGE_PHP,		// PHP, as supported by DBG.
@@ -143,6 +145,7 @@ struct ReplyRequiredInfo {
 class GDBAgent: public TTYAgent {
 public:
     DECLARE_TYPE_INFO
+    DebuggerCPU cpu;
 
 protected:
     enum State {
@@ -441,6 +444,14 @@ public:
     }
     ProgramLanguage program_language(string text);
 
+    // True if debugger can enable breakpoints
+    bool has_disassembly() const
+    { 
+      return type() == GDB 
+	// || type() == PYDB  // In theory this could be done.
+	;
+    }
+
     // True if debugger can enable breakpoints
     bool has_enable_command() const
     { 
@@ -477,9 +488,9 @@ public:
     // change at any time)
     bool has_volatile_breakpoints() const
     {
-	return type() == GDB || type() == XDB || 
-	       type() == DBX || type() == PYDB || type() == PERL || 
-	       type() == DBG;
+	return type() == DBG  || type() == DBX  || type() == GDB 
+	  ||   type() == MAKE || type() == PERL || type() == PYDB 
+	  ||   type() == XDB;
     }
 
     // True if debugger supports I/O redirection
@@ -500,7 +511,7 @@ public:
     bool has_system_calls() const
     {
 	return type() == GDB || type() == XDB || type() == DBX || 
-	       type() == PERL;
+	  type() == PYDB || type() == PERL;
     }
 
     // True if debugger supports loading and examining executables
@@ -530,15 +541,20 @@ public:
     // True if debugger supports `cd'
     bool has_cd_command() const
     {
-      return type() == GDB || type() == XDB || 
-	type() == DBX || type() == PYDB || type() == PERL || type() == BASH;
+      return type() == BASH || type() == GDB || type() == DBX 
+	|| type() == PERL || type() == PYDB  || type() == XDB;
     }
 
     // True if debugger supports `shell'
     bool has_shell_command() const
     {
-      return type() == GDB || type() == XDB || type() == DBX || 
-	type() == PERL || type() == BASH ;
+      return type() == BASH 
+	|| type() == DBX 
+	|| type() == GDB 
+	|| type() == PERL 
+	|| type() == PYDB
+	|| type() == MAKE
+	|| type() == XDB;
     }
 
     // True if debugger has numbered breakpoints
@@ -567,8 +583,10 @@ public:
     // True if debugger supports breakpoint commands
     bool has_breakpoint_commands() const
     {
-        return type() == GDB || type() == XDB || type() == BASH || 
-	       has_when_command() || type() == PERL;
+        return type() == BASH || type() == GDB 
+	  || type() == MAKE || has_when_command() || type() == PERL 
+	  || type() == PYDB || type() == XDB 
+	  ;
     }
 
     // True if debugger has typed pointers, as in `(TYPE)0x0'
@@ -598,7 +616,7 @@ public:
     // True if `display X' automatically prints X
     bool display_prints_values() const
     {
-      return type() == GDB || type() == PYDB || type() == BASH;
+      return type() == GDB || type() == PYDB ;
     }
 
     // True if debugger can enable displays
