@@ -9,7 +9,7 @@
 // DDD is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// version 3 of the License, or (at your option) any later version.
 // 
 // DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,8 +18,7 @@
 // 
 // You should have received a copy of the GNU General Public
 // License along with DDD -- see the file COPYING.
-// If not, write to the Free Software Foundation, Inc.,
-// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// If not, see <http://www.gnu.org/licenses/>.
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
@@ -56,14 +55,15 @@ class PosBuffer {
     string auto_cmd_part;	// Prefix of AutoCommand found
 
 protected:
-    void filter_gdb(string& answer);
-    void filter_dbx(string& answer);
-    void filter_xdb(string& answer);
-    void filter_jdb(string& answer);
-    void filter_pydb(string& answer);
-    void filter_dbg(string& answer);
-    void filter_perl(string& answer);
     void filter_bash(string& answer);
+    void filter_dbg(string& answer);
+    void filter_dbx(string& answer);
+    void filter_gdb(string& answer);
+    void filter_jdb(string& answer);
+    void filter_perl(string& answer);
+    void filter_pydb(string& answer);
+    void filter_make(string& answer);
+    void filter_xdb(string& answer);
 
     // Filter all lines from ANSWER beginning with current line.  This
     // is required to suppress the line number output after a
