@@ -1,304 +1,304 @@
 "#line 1 \"ddd.vsl\"\n"
 "#line 1 \"<built-in>\"\n"
-"#line 1 \"<command line>\"\n"
+"#line 1 \"<command-line>\"\n"
 "#line 1 \"ddd.vsl\"\n"
+"#line 30 \"ddd.vsl\"\n"
+"#line 1 \"./../vsllib/std.vsl\"\n"
+"#line 28 \"./../vsllib/std.vsl\"\n"
+"#line 1 \"./../vsllib/builtin.vsl\"\n"
+"#line 31 \"./../vsllib/builtin.vsl\"\n"
+"__op_halign(...);\n"
+"__op_valign(...);\n"
+"__op_ualign(...);\n"
+"__op_talign(...);\n"
+"__op_plus(...);\n"
+"__op_mult(...);\n"
+"__op_cons(...);\n"
+"__op_minus(a, b);\n"
+"__op_div(a, b);\n"
+"__op_mod(a, b);\n"
+"__op_eq(a, b);\n"
+"__op_ne(a, b);\n"
+"__op_gt(a, b);\n"
+"__op_ge(a, b);\n"
+"__op_lt(a, b);\n"
+"__op_le(a, b);\n"
+"__op_not(a);\n"
+"\n"
+"\n"
+"__hspace(box);\n"
+"__vspace(box);\n"
+"__hfix(box);\n"
+"__vfix(box);\n"
+"__rise(linethickness);\n"
+"__fall(linethickness);\n"
+"__arc(start, length, linethickness);\n"
+"__square(box);\n"
+"__tag(box);\n"
+"__string(box);\n"
+"__chars(box);\n"
+"__font(box, font);\n"
+"__fontfix(box);\n"
+"__background(box, color);\n"
+"__foreground(box, color);\n"
+"\n"
+"\n"
+"__fill();\n"
+"__rule();\n"
+"__diag();\n"
+"\n"
+"\n"
+"__fail(...);\n"
+"__undef();\n"
+"\n"
+"\n"
+"\n"
+"\n"
+"\n"
+"(&)(...) = __op_halign(...);\n"
+"(|)(...) = __op_valign(...);\n"
+"(^)(...) = __op_ualign(...);\n"
+"(~)(...) = __op_talign(...);\n"
+"(+)(...) = __op_plus(...);\n"
+"(*)(...) = __op_mult(...);\n"
+"(::)(...) = __op_cons(...);\n"
+"(-)(a, b) = __op_minus(a, b);\n"
+"(/)(a, b) = __op_div(a, b);\n"
+"(%)(a, b) = __op_mod(a, b);\n"
+"(=)(a, b) = __op_eq(a, b);\n"
+"(<>)(a, b) = __op_ne(a, b);\n"
+"(>)(a, b) = __op_gt(a, b);\n"
+"(>=)(a, b) = __op_ge(a, b);\n"
+"(<)(a, b) = __op_lt(a, b);\n"
+"(<=)(a, b) = __op_le(a, b);\n"
+"(not)(a) = __op_not(a);\n"
+"\n"
+"\n"
+"hspace(box) = __hspace(box);\n"
+"vspace(box) = __vspace(box);\n"
+"hfix(box) = __hfix(box);\n"
+"vfix(box) = __vfix(box);\n"
+"rise(linethickness) = __rise(linethickness);\n"
+"fall(linethickness) = __fall(linethickness);\n"
+"arc(start, length, linethickness) = __arc(start, length, linethickness);\n"
+"square(box) = __square(box);\n"
+"tag(box) = __tag(box);\n"
+"string(box) = __string(box);\n"
+"chars(box) = __chars(box);\n"
+"font(box, font) = __font(box, font);\n"
+"fontfix(box) = __fontfix(box);\n"
+"background(box, color) = __background(box, color);\n"
+"foreground(box, color) = __foreground(box, color);\n"
+"fill() = __fill();\n"
+"rule() = __rule();\n"
+"diag() = __diag();\n"
+"fail() = __fail();\n"
+"fail(message) = __fail(message);\n"
+"undef() = __undef();\n"
+"#line 29 \"./../vsllib/std.vsl\"\n"
+"\n"
+"\n"
+"std_version() = \"$Id$\";\n"
+"\n"
+"\n"
+"rulethickness() = 1;\n"
+"whitethickness() = 2;\n"
+"indentamount() = hspace(\"  \");\n"
+"true = 1;\n"
+"false = 0;\n"
+"\n"
+"\n"
+"\n"
+"\n"
+"max(a) = a;\n"
+"max(a, b, ...) = if a > b then max(a, ...) else max(b, ...) fi;\n"
+"min(a) = a;\n"
+"min(a, b, ...) = if a < b then min(a, ...) else min(b, ...) fi;\n"
+"\n"
+"\n"
+"hfill() = vfix(fill());\n"
+"vfill() = hfix(fill());\n"
+"\n"
+"\n"
+"hnull() = vfill();\n"
+"vnull() = hfill();\n"
+"\n"
+"\n"
+"hrule(thickness) = rule() & vspace(thickness);\n"
+"vrule(thickness) = rule() | hspace(thickness);\n"
+"hwhite(thickness) = fill() & vspace(thickness);\n"
+"vwhite(thickness) = fill() | hspace(thickness);\n"
+"\n"
+"hrule() = hrule(rulethickness());\n"
+"vrule() = vrule(rulethickness());\n"
+"hwhite() = hwhite(whitethickness());\n"
+"vwhite() = vwhite(whitethickness());\n"
+"\n"
+"\n"
+"fix(a) = hfix(vfix(a));\n"
+"space(a) = hspace(a) + vspace(a);\n"
+"\n"
+"\n"
+"box(x) = x;\n"
+"box(x,y) = hspace(x) + vspace(y);\n"
+"\n"
+"\n"
+"halign(...) = (&)(...);\n"
+"valign(...) = (|)(...);\n"
+"talign(...) = (~)(...);\n"
+"\n"
+"\n"
+"hralign() = hnull();\n"
+"hralign(head) = head;\n"
+"hralign(head, ...) = hralign(...) & head;\n"
+"tralign() = hnull();\n"
+"tralign(head) = head;\n"
+"tralign(head, ...) = tralign(...) ~ head;\n"
+"vralign() = vnull();\n"
+"vralign(head) = head;\n"
+"vralign(head, ...) = vralign(...) | head;\n"
+"\n"
+"\n"
+"hlist(_) = hnull();\n"
+"hlist(_, head) = head;\n"
+"hlist(sep, head, ...) = head & sep & hlist(sep, ...);\n"
+"\n"
+"tlist(_) = hnull();\n"
+"tlist(_, head) = head;\n"
+"tlist(sep, head, ...) = head ~ sep ~ tlist(sep, ...);\n"
+"\n"
+"vlist(_) = vnull();\n"
+"vlist(_, head) = head;\n"
+"vlist(sep, head, ...) = head | sep | vlist(sep, ...);\n"
+"\n"
+"hvlist(_) = vnull();\n"
+"hvlist(sep, head) = head & sep;\n"
+"hvlist(sep, head, ...) = head & sep | hvlist(sep, ...);\n"
+"\n"
+"tvlist(_) = vnull();\n"
+"tvlist(sep, head) = head ~ sep;\n"
+"tvlist(sep, head, ...) = head ~ sep | tvlist(sep, ...);\n"
+"\n"
+"vhlist(_) = vnull();\n"
+"vhlist(sep, head) = head | sep;\n"
+"vhlist(sep, head, ...) = (head | sep) & vhlist(sep, ...);\n"
+"\n"
+"vtlist(_) = vnull();\n"
+"vtlist(sep, head) = head | sep;\n"
+"vtlist(sep, head, ...) = (head | sep) ~ vtlist(sep, ...);\n"
+"\n"
+"commalist(...) = tlist(\", \", ...);\n"
+"semicolonlist(...) = tlist(\"; \", ...);\n"
+"\n"
+"\n"
+"heven(box, align) = box ^ hspace(box + box % align);\n"
+"veven(box, align) = box ^ vspace(box + box % align);\n"
+"even(box, align) = heven(veven(box, align), align);\n"
+"heven(box) = heven(box, 2);\n"
+"veven(box) = veven(box, 2);\n"
+"even(box) = heven(veven(box));\n"
+"\n"
+"\n"
+"\n"
+"num(a);\n"
+"digit(0) = \"0\";\n"
+"digit(1) = \"1\";\n"
+"digit(2) = \"2\";\n"
+"digit(3) = \"3\";\n"
+"digit(4) = \"4\";\n"
+"digit(5) = \"5\";\n"
+"digit(6) = \"6\";\n"
+"digit(7) = \"7\";\n"
+"digit(8) = \"8\";\n"
+"digit(9) = \"9\";\n"
+"digit(10) = \"a\";\n"
+"digit(11) = \"b\";\n"
+"digit(12) = \"c\";\n"
+"digit(13) = \"d\";\n"
+"digit(14) = \"e\";\n"
+"digit(15) = \"f\";\n"
+"digit(_) = fail(\"invalid digit() argument\");\n"
+"\n"
+"\n"
+"\n"
+"pnum(a, base) =\n"
+"if a < base then\n"
+"digit(a)\n"
+"else\n"
+"pnum(a / base, base) & pnum(a % base, base)\n"
+"fi;\n"
+"\n"
+"\n"
+"num(a, base) =\n"
+"if a < 0 then \"-\" & pnum(0 - a, base) else pnum(a, base) fi;\n"
+"num(a) = num(a, 10);\n"
+"\n"
+"\n"
+"dec(a) = num(a, 10);\n"
+"oct(a) = num(a, 8);\n"
+"bin(a) = num(a, 2);\n"
+"hex(a) = num(a, 16);\n"
+"\n"
+"\n"
+"n_rule() = hrule() | hwhite();\n"
+"w_rule() = vrule() & vwhite();\n"
+"s_rule() = hwhite() | hrule();\n"
+"e_rule() = vwhite() & vrule();\n"
+"\n"
+"\n"
+"whiteframe(box, thickness) =\n"
+"hwhite(thickness)\n"
+"| vwhite(thickness) & box & vwhite(thickness)\n"
+"| hwhite(thickness);\n"
+"whiteframe(box) = whiteframe(box, whitethickness());\n"
+"\n"
+"ruleframe(box, thickness) =\n"
+"hrule(thickness)\n"
+"| vrule(thickness) & box & vrule(thickness)\n"
+"| hrule(thickness);\n"
+"ruleframe(box) = ruleframe(box, rulethickness());\n"
+"\n"
+"frame(box) = ruleframe(whiteframe(box));\n"
+"doubleframe(box) = frame(frame(box));\n"
+"thickframe(box) = ruleframe(frame(box));\n"
+"\n"
+"\n"
+"hcenter(box) = fill() & box & fill();\n"
+"vcenter(box) = fill() | box | fill();\n"
+"center(box) = hcenter(vcenter(box));\n"
+"\n"
+"\n"
+"n_flush(box) = hcenter(box) | fill();\n"
+"s_flush(box) = fill() | hcenter(box);\n"
+"w_flush(box) = vcenter(box) & fill();\n"
+"e_flush(box) = fill() & vcenter(box);\n"
+"sw_flush(box) = fill() | (box & fill());\n"
+"nw_flush(box) = (box & fill()) | fill();\n"
+"se_flush(box) = fill() | (fill() & box);\n"
+"ne_flush(box) = (fill() & box) | fill();\n"
+"\n"
+"\n"
+"indent(box) = indentamount() & box;\n"
+"\n"
+"\n"
+"underline(box) = box | hrule();\n"
+"overline(box) = hrule() | box;\n"
+"crossline(box) = hfix(box ^ vcenter(hrule()));\n"
+"\n"
+"\n"
+"doublestrike(box) = box ^ (hspace(1) & box);\n"
+"\n"
+"\n"
+"dquote() = \"\\\"\";\n"
+"squote() = \"'\";\n"
+"copyright() = \"(c)\";\n"
 "#line 31 \"ddd.vsl\"\n"
-"#line 1 \"./../vsllib/std.vsl\"\n"
-"#line 29 \"./../vsllib/std.vsl\"\n"
-"#line 1 \"./../vsllib/builtin.vsl\"\n"
-"#line 32 \"./../vsllib/builtin.vsl\"\n"
-"__op_halign(...);\n"
-"__op_valign(...);\n"
-"__op_ualign(...);\n"
-"__op_talign(...);\n"
-"__op_plus(...);\n"
-"__op_mult(...);\n"
-"__op_cons(...);\n"
-"__op_minus(a, b);\n"
-"__op_div(a, b);\n"
-"__op_mod(a, b);\n"
-"__op_eq(a, b);\n"
-"__op_ne(a, b);\n"
-"__op_gt(a, b);\n"
-"__op_ge(a, b);\n"
-"__op_lt(a, b);\n"
-"__op_le(a, b);\n"
-"__op_not(a);\n"
-"\n"
-"\n"
-"__hspace(box);\n"
-"__vspace(box);\n"
-"__hfix(box);\n"
-"__vfix(box);\n"
-"__rise(linethickness);\n"
-"__fall(linethickness);\n"
-"__arc(start, length, linethickness);\n"
-"__square(box);\n"
-"__tag(box);\n"
-"__string(box);\n"
-"__chars(box);\n"
-"__font(box, font);\n"
-"__fontfix(box);\n"
-"__background(box, color);\n"
-"__foreground(box, color);\n"
-"\n"
-"\n"
-"__fill();\n"
-"__rule();\n"
-"__diag();\n"
-"\n"
-"\n"
-"__fail(...);\n"
-"__undef();\n"
-"\n"
-"\n"
-"\n"
-"\n"
-"\n"
-"(&)(...) = __op_halign(...);\n"
-"(|)(...) = __op_valign(...);\n"
-"(^)(...) = __op_ualign(...);\n"
-"(~)(...) = __op_talign(...);\n"
-"(+)(...) = __op_plus(...);\n"
-"(*)(...) = __op_mult(...);\n"
-"(::)(...) = __op_cons(...);\n"
-"(-)(a, b) = __op_minus(a, b);\n"
-"(/)(a, b) = __op_div(a, b);\n"
-"(%)(a, b) = __op_mod(a, b);\n"
-"(=)(a, b) = __op_eq(a, b);\n"
-"(<>)(a, b) = __op_ne(a, b);\n"
-"(>)(a, b) = __op_gt(a, b);\n"
-"(>=)(a, b) = __op_ge(a, b);\n"
-"(<)(a, b) = __op_lt(a, b);\n"
-"(<=)(a, b) = __op_le(a, b);\n"
-"(not)(a) = __op_not(a);\n"
-"\n"
-"\n"
-"hspace(box) = __hspace(box);\n"
-"vspace(box) = __vspace(box);\n"
-"hfix(box) = __hfix(box);\n"
-"vfix(box) = __vfix(box);\n"
-"rise(linethickness) = __rise(linethickness);\n"
-"fall(linethickness) = __fall(linethickness);\n"
-"arc(start, length, linethickness) = __arc(start, length, linethickness);\n"
-"square(box) = __square(box);\n"
-"tag(box) = __tag(box);\n"
-"string(box) = __string(box);\n"
-"chars(box) = __chars(box);\n"
-"font(box, font) = __font(box, font);\n"
-"fontfix(box) = __fontfix(box);\n"
-"background(box, color) = __background(box, color);\n"
-"foreground(box, color) = __foreground(box, color);\n"
-"fill() = __fill();\n"
-"rule() = __rule();\n"
-"diag() = __diag();\n"
-"fail() = __fail();\n"
-"fail(message) = __fail(message);\n"
-"undef() = __undef();\n"
-"#line 30 \"./../vsllib/std.vsl\"\n"
-"\n"
-"\n"
-"std_version() = \"$Id$\";\n"
-"\n"
-"\n"
-"rulethickness() = 1;\n"
-"whitethickness() = 2;\n"
-"indentamount() = hspace(\"  \");\n"
-"true = 1;\n"
-"false = 0;\n"
-"\n"
-"\n"
-"\n"
-"\n"
-"max(a) = a;\n"
-"max(a, b, ...) = if a > b then max(a, ...) else max(b, ...) fi;\n"
-"min(a) = a;\n"
-"min(a, b, ...) = if a < b then min(a, ...) else min(b, ...) fi;\n"
-"\n"
-"\n"
-"hfill() = vfix(fill());\n"
-"vfill() = hfix(fill());\n"
-"\n"
-"\n"
-"hnull() = vfill();\n"
-"vnull() = hfill();\n"
-"\n"
-"\n"
-"hrule(thickness) = rule() & vspace(thickness);\n"
-"vrule(thickness) = rule() | hspace(thickness);\n"
-"hwhite(thickness) = fill() & vspace(thickness);\n"
-"vwhite(thickness) = fill() | hspace(thickness);\n"
-"\n"
-"hrule() = hrule(rulethickness());\n"
-"vrule() = vrule(rulethickness());\n"
-"hwhite() = hwhite(whitethickness());\n"
-"vwhite() = vwhite(whitethickness());\n"
-"\n"
-"\n"
-"fix(a) = hfix(vfix(a));\n"
-"space(a) = hspace(a) + vspace(a);\n"
-"\n"
-"\n"
-"box(x) = x;\n"
-"box(x,y) = hspace(x) + vspace(y);\n"
-"\n"
-"\n"
-"halign(...) = (&)(...);\n"
-"valign(...) = (|)(...);\n"
-"talign(...) = (~)(...);\n"
-"\n"
-"\n"
-"hralign() = hnull();\n"
-"hralign(head) = head;\n"
-"hralign(head, ...) = hralign(...) & head;\n"
-"tralign() = hnull();\n"
-"tralign(head) = head;\n"
-"tralign(head, ...) = tralign(...) ~ head;\n"
-"vralign() = vnull();\n"
-"vralign(head) = head;\n"
-"vralign(head, ...) = vralign(...) | head;\n"
-"\n"
-"\n"
-"hlist(_) = hnull();\n"
-"hlist(_, head) = head;\n"
-"hlist(sep, head, ...) = head & sep & hlist(sep, ...);\n"
-"\n"
-"tlist(_) = hnull();\n"
-"tlist(_, head) = head;\n"
-"tlist(sep, head, ...) = head ~ sep ~ tlist(sep, ...);\n"
-"\n"
-"vlist(_) = vnull();\n"
-"vlist(_, head) = head;\n"
-"vlist(sep, head, ...) = head | sep | vlist(sep, ...);\n"
-"\n"
-"hvlist(_) = vnull();\n"
-"hvlist(sep, head) = head & sep;\n"
-"hvlist(sep, head, ...) = head & sep | hvlist(sep, ...);\n"
-"\n"
-"tvlist(_) = vnull();\n"
-"tvlist(sep, head) = head ~ sep;\n"
-"tvlist(sep, head, ...) = head ~ sep | tvlist(sep, ...);\n"
-"\n"
-"vhlist(_) = vnull();\n"
-"vhlist(sep, head) = head | sep;\n"
-"vhlist(sep, head, ...) = (head | sep) & vhlist(sep, ...);\n"
-"\n"
-"vtlist(_) = vnull();\n"
-"vtlist(sep, head) = head | sep;\n"
-"vtlist(sep, head, ...) = (head | sep) ~ vtlist(sep, ...);\n"
-"\n"
-"commalist(...) = tlist(\", \", ...);\n"
-"semicolonlist(...) = tlist(\"; \", ...);\n"
-"\n"
-"\n"
-"heven(box, align) = box ^ hspace(box + box % align);\n"
-"veven(box, align) = box ^ vspace(box + box % align);\n"
-"even(box, align) = heven(veven(box, align), align);\n"
-"heven(box) = heven(box, 2);\n"
-"veven(box) = veven(box, 2);\n"
-"even(box) = heven(veven(box));\n"
-"\n"
-"\n"
-"\n"
-"num(a);\n"
-"digit(0) = \"0\";\n"
-"digit(1) = \"1\";\n"
-"digit(2) = \"2\";\n"
-"digit(3) = \"3\";\n"
-"digit(4) = \"4\";\n"
-"digit(5) = \"5\";\n"
-"digit(6) = \"6\";\n"
-"digit(7) = \"7\";\n"
-"digit(8) = \"8\";\n"
-"digit(9) = \"9\";\n"
-"digit(10) = \"a\";\n"
-"digit(11) = \"b\";\n"
-"digit(12) = \"c\";\n"
-"digit(13) = \"d\";\n"
-"digit(14) = \"e\";\n"
-"digit(15) = \"f\";\n"
-"digit(_) = fail(\"invalid digit() argument\");\n"
-"\n"
-"\n"
-"\n"
-"pnum(a, base) =\n"
-"if a < base then\n"
-"digit(a)\n"
-"else\n"
-"pnum(a / base, base) & pnum(a % base, base)\n"
-"fi;\n"
-"\n"
-"\n"
-"num(a, base) =\n"
-"if a < 0 then \"-\" & pnum(0 - a, base) else pnum(a, base) fi;\n"
-"num(a) = num(a, 10);\n"
-"\n"
-"\n"
-"dec(a) = num(a, 10);\n"
-"oct(a) = num(a, 8);\n"
-"bin(a) = num(a, 2);\n"
-"hex(a) = num(a, 16);\n"
-"\n"
-"\n"
-"n_rule() = hrule() | hwhite();\n"
-"w_rule() = vrule() & vwhite();\n"
-"s_rule() = hwhite() | hrule();\n"
-"e_rule() = vwhite() & vrule();\n"
-"\n"
-"\n"
-"whiteframe(box, thickness) =\n"
-"hwhite(thickness)\n"
-"| vwhite(thickness) & box & vwhite(thickness)\n"
-"| hwhite(thickness);\n"
-"whiteframe(box) = whiteframe(box, whitethickness());\n"
-"\n"
-"ruleframe(box, thickness) =\n"
-"hrule(thickness)\n"
-"| vrule(thickness) & box & vrule(thickness)\n"
-"| hrule(thickness);\n"
-"ruleframe(box) = ruleframe(box, rulethickness());\n"
-"\n"
-"frame(box) = ruleframe(whiteframe(box));\n"
-"doubleframe(box) = frame(frame(box));\n"
-"thickframe(box) = ruleframe(frame(box));\n"
-"\n"
-"\n"
-"hcenter(box) = fill() & box & fill();\n"
-"vcenter(box) = fill() | box | fill();\n"
-"center(box) = hcenter(vcenter(box));\n"
-"\n"
-"\n"
-"n_flush(box) = hcenter(box) | fill();\n"
-"s_flush(box) = fill() | hcenter(box);\n"
-"w_flush(box) = vcenter(box) & fill();\n"
-"e_flush(box) = fill() & vcenter(box);\n"
-"sw_flush(box) = fill() | (box & fill());\n"
-"nw_flush(box) = (box & fill()) | fill();\n"
-"se_flush(box) = fill() | (fill() & box);\n"
-"ne_flush(box) = (fill() & box) | fill();\n"
-"\n"
-"\n"
-"indent(box) = indentamount() & box;\n"
-"\n"
-"\n"
-"underline(box) = box | hrule();\n"
-"overline(box) = hrule() | box;\n"
-"crossline(box) = hfix(box ^ vcenter(hrule()));\n"
-"\n"
-"\n"
-"doublestrike(box) = box ^ (hspace(1) & box);\n"
-"\n"
-"\n"
-"dquote() = \"\\\"\";\n"
-"squote() = \"'\";\n"
-"copyright() = \"(c)\";\n"
-"#line 32 \"ddd.vsl\"\n"
 "#line 1 \"./../vsllib/tab.vsl\"\n"
-"#line 29 \"./../vsllib/tab.vsl\"\n"
+"#line 28 \"./../vsllib/tab.vsl\"\n"
 "#line 1 \"./../vsllib/std.vsl\"\n"
-"#line 29 \"./../vsllib/std.vsl\"\n"
+"#line 28 \"./../vsllib/std.vsl\"\n"
 "#line 1 \"./../vsllib/builtin.vsl\"\n"
-"#line 32 \"./../vsllib/builtin.vsl\"\n"
+"#line 31 \"./../vsllib/builtin.vsl\"\n"
 "__op_halign(...);\n"
 "__op_valign(...);\n"
 "__op_ualign(...);\n"
@@ -387,7 +387,7 @@
 "fail() = __fail();\n"
 "fail(message) = __fail(message);\n"
 "undef() = __undef();\n"
-"#line 30 \"./../vsllib/std.vsl\"\n"
+"#line 29 \"./../vsllib/std.vsl\"\n"
 "\n"
 "\n"
 "std_version() = \"$Id$\";\n"
@@ -584,11 +584,11 @@
 "dquote() = \"\\\"\";\n"
 "squote() = \"'\";\n"
 "copyright() = \"(c)\";\n"
-"#line 30 \"./../vsllib/tab.vsl\"\n"
+"#line 29 \"./../vsllib/tab.vsl\"\n"
 "\n"
 "\n"
 "tab_version() = \"$Id$\";\n"
-"#line 47 \"./../vsllib/tab.vsl\"\n"
+"#line 46 \"./../vsllib/tab.vsl\"\n"
 "tab_elem([]) = tab_elem(0);\n"
 "tab_elem(x) = whiteframe(x);\n"
 "\n"
@@ -669,9 +669,9 @@
 "hrule()\n"
 "| _dtab(_tab_width(...), ...)\n"
 "| hrule();\n"
-"#line 33 \"ddd.vsl\"\n"
+"#line 32 \"ddd.vsl\"\n"
 "#line 1 \"./../vsllib/fonts.vsl\"\n"
-"#line 30 \"./../vsllib/fonts.vsl\"\n"
+"#line 29 \"./../vsllib/fonts.vsl\"\n"
 "fonts_version() = \"$Id$\";\n"
 "\n"
 "\n"
@@ -802,21 +802,21 @@
 "\n"
 "sl(...) = it(...);\n"
 "bs(...) = bi(...);\n"
-"#line 34 \"ddd.vsl\"\n"
+"#line 33 \"ddd.vsl\"\n"
 "#line 1 \"./../vsllib/colors.vsl\"\n"
-"#line 30 \"./../vsllib/colors.vsl\"\n"
+"#line 29 \"./../vsllib/colors.vsl\"\n"
 "colors_version() = \"$Id$\";\n"
 "\n"
 "\n"
 "color(box, fg, bg) = foreground(background(box, bg), fg);\n"
 "color(box, fg) = foreground(box, fg);\n"
-"#line 35 \"ddd.vsl\"\n"
+"#line 34 \"ddd.vsl\"\n"
 "#line 1 \"./../vsllib/list.vsl\"\n"
-"#line 29 \"./../vsllib/list.vsl\"\n"
+"#line 28 \"./../vsllib/list.vsl\"\n"
 "#line 1 \"./../vsllib/std.vsl\"\n"
-"#line 29 \"./../vsllib/std.vsl\"\n"
+"#line 28 \"./../vsllib/std.vsl\"\n"
 "#line 1 \"./../vsllib/builtin.vsl\"\n"
-"#line 32 \"./../vsllib/builtin.vsl\"\n"
+"#line 31 \"./../vsllib/builtin.vsl\"\n"
 "__op_halign(...);\n"
 "__op_valign(...);\n"
 "__op_ualign(...);\n"
@@ -905,7 +905,7 @@
 "fail() = __fail();\n"
 "fail(message) = __fail(message);\n"
 "undef() = __undef();\n"
-"#line 30 \"./../vsllib/std.vsl\"\n"
+"#line 29 \"./../vsllib/std.vsl\"\n"
 "\n"
 "\n"
 "std_version() = \"$Id$\";\n"
@@ -1102,7 +1102,7 @@
 "dquote() = \"\\\"\";\n"
 "squote() = \"'\";\n"
 "copyright() = \"(c)\";\n"
-"#line 30 \"./../vsllib/list.vsl\"\n"
+"#line 29 \"./../vsllib/list.vsl\"\n"
 "\n"
 "\n"
 "list_version() = \"$Id$\";\n"
@@ -1235,7 +1235,7 @@
 "_list(atom) = atom;\n"
 "list([]) = \"[]\";\n"
 "list(l) = \"[\" & _list(l) & \"]\";\n"
-"#line 36 \"ddd.vsl\"\n"
+"#line 35 \"ddd.vsl\"\n"
 "\n"
 "\n"
 "#pragma replace stdfontfamily\n"
