@@ -10,7 +10,7 @@
 // DDD is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// version 3 of the License, or (at your option) any later version.
 // 
 // DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,8 +19,7 @@
 // 
 // You should have received a copy of the GNU General Public
 // License along with DDD -- see the file COPYING.
-// If not, write to the Free Software Foundation, Inc.,
-// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// If not, see <http://www.gnu.org/licenses/>.
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
@@ -67,6 +66,9 @@ bool is_perl_file(const string& file_name);
 // True if FILE_NAME is a BASH file
 bool is_bash_file(const string& file_name);
 
+// True if FILE_NAME is a MAKE file
+bool is_make_file(const string& file_name);
+
 // True if FILE_NAME is a PHP file
 bool is_php_file(const string& file_name);
 
