@@ -2,6 +2,7 @@
 // Regular expressions used in DDD
 
 // Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
+// Copyright (C) 2008 Free Software Foundation, Inc.
 // Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
@@ -9,7 +10,7 @@
 // DDD is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// version 3 of the License, or (at your option) any later version.
 // 
 // DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,8 +19,7 @@
 // 
 // You should have received a copy of the GNU General Public
 // License along with DDD -- see the file COPYING.
-// If not, write to the Free Software Foundation, Inc.,
-// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// If not, see <http://www.gnu.org/licenses/>.
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
@@ -42,6 +42,9 @@ extern const regex rxalpha;
 extern const regex rxalphanum;
 extern const regex rxarglist;
 extern const regex rxat;
+extern const regex rxbashpos;
+extern const regex rxbashprompt;
+extern const regex rxbashref;
 extern const regex rxblank;
 extern const regex rxblanks;
 extern const regex rxblanks_or_tabs;
@@ -54,12 +57,15 @@ extern const regex rxcore;
 extern const regex rxcore_cmd;
 extern const regex rxcrlf;
 extern const regex rxdata;
+extern const regex rxdbgframepos;
+extern const regex rxdbgpos;
+extern const regex rxdbx_baseclass;
 extern const regex rxdbx_begin_of_display;
 extern const regex rxdbx_begin_of_display_info;
 extern const regex rxdbx_scope;
 extern const regex rxdbxframe;
-extern const regex rxdbxfunc;
 extern const regex rxdbxfunc2;
+extern const regex rxdbxfunc;
 extern const regex rxdbxpos;
 extern const regex rxdbxwarn1;
 extern const regex rxdbxwarn2;
@@ -73,6 +79,7 @@ extern const regex rxdisplay_cmd_and_args;
 extern const regex rxdont;
 extern const regex rxdotdot;
 extern const regex rxdouble;
+extern const regex rxdoubleindex;
 extern const regex rxdown_cmd;
 extern const regex rxenable;
 extern const regex rxenter_file_name;
@@ -80,9 +87,11 @@ extern const regex rxeqeq;
 extern const regex rxfile_cmd;
 extern const regex rxfilepath;
 extern const regex rxfilepos;
+extern const regex rxfixednum;
+extern const regex rxfloat;
 extern const regex rxframe_addr;
-extern const regex rxframe_func;
 extern const regex rxframe_cmd;
+extern const regex rxframe_func;
 extern const regex rxfunction_call;
 extern const regex rxgdb_begin_of_display;
 extern const regex rxgdb_begin_of_display_info;
@@ -94,14 +103,17 @@ extern const regex rxint;
 extern const regex rxinvalid_value;
 extern const regex rxjdbpos;
 extern const regex rxjdbprompt;
-extern const regex rxjdbprompt_reverse;
 extern const regex rxjdbprompt_nothread;
+extern const regex rxjdbprompt_reverse;
 extern const regex rxlist_cmd;
 extern const regex rxlist_range;
 extern const regex rxlookup_cmd;
 extern const regex rxlowercase;
 extern const regex rxm3comment;
 extern const regex rxmake_cmd;
+extern const regex rxmakepos;
+extern const regex rxmakeprompt;
+extern const regex rxmakeref;
 extern const regex rxmembers_of_nl;
 extern const regex rxmore_than_one;
 extern const regex rxname_colon_int_nl;
@@ -122,12 +134,11 @@ extern const regex rxpc;
 extern const regex rxperlpos;
 extern const regex rxperlprompt;
 extern const regex rxperlref;
-extern const regex rxbashpos;
-extern const regex rxbashprompt;
-extern const regex rxbashref;
 extern const regex rxprocess1;
 extern const regex rxprocess2;
 extern const regex rxprompt;
+extern const regex rxpypos;
+extern const regex rxpyprompt;
 extern const regex rxq;
 extern const regex rxreference;
 extern const regex rxrefresh_cmd;
@@ -148,12 +159,12 @@ extern const regex rxsingle_display_cmd;
 extern const regex rxspace;
 extern const regex rxstopped_addr;
 extern const regex rxstopped_func;
+extern const regex rxstring;
 extern const regex rxstruct_begin;
 extern const regex rxstruct_end;
 extern const regex rxstruct_keyword_begin;
 extern const regex rxterminated;
 extern const regex rxthread_cmd;
-extern const regex rxdbx_baseclass;
 extern const regex rxundisplay;
 extern const regex rxup_cmd;
 extern const regex rxuppercase;
@@ -164,9 +175,6 @@ extern const regex rxwhen;
 extern const regex rxwhite;
 extern const regex rxxdb;
 extern const regex rxxdbpos;
-extern const regex rxdoubleindex;
-extern const regex rxdbgpos;
-extern const regex rxdbgframepos;
 
 #endif // !RUNTIME_REGEX
 
